
Measures
========

This application provides the following measures:

.. list-table::
   :widths: 15 30 10
   :header-rows: 1

   * - Measurement
     - Units Accepted
     - Standard Unit
     - Notes
   * - Distance
     - chain, chain_benoit, chain_sears, british_chain_benoit, british_chain_sears, british_chain_sears_truncated, cm, british_ft, british_yd, clarke_ft, clarke_link, fathom, ft, german_m, gold_coast_ft, indian_yd, inch, km, link, link_benoit, link_sears, m, mi, mm, nm, nm_uk, rod, sears_yd, survey_ft, um, yd
     - m
   * - Area
     - sq_chain, sq_chain_benoit, sq_chain_sears, sq_british_chain_benoit, sq_british_chain_sears, sq_british_chain_sears_truncated, sq_cm, sq_british_ft, sq_british_yd, sq_clarke_ft, sq_clarke_link, sq_fathom, sq_ft, sq_german_m, sq_gold_coast_ft, sq_indian_yd, sq_inch, sq_km, sq_link, sq_link_benoit, sq_link_sears, sq_m, sq_mi, sq_mm, sq_nm, sq_nm_uk, sq_rod, sq_sears_yd, sq_survey_ft, sq_um, sq_yd
     - sq_m
   * - Weight
     - mcg, mg, g, kg, tonne, oz, lb, stone, short_ton, long_ton
     - g
   * - Volume
     - us_g, us_qt, us_pint, us_cup, us_oz, us_tbsp, us_tsp, cubic_centimeter, cubic_meter, l, ml, cubic_foot, cubic_inch, imperial_g, imperial_qt, imperial_pint, imperial_oz, imperial_tbsp, imperial_tsp
     - cubic_meter
   * - Temperature
     - f, c, k
     - k
